#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-8xbEjtWN3gHDA6mYysGdyL
key:                  haskell-language-server-2.3.0.0-8xbEjtWN3gHDA6mYysGdyL
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4ff00ba351036ac21bb2c84f8cf00711
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-8xbEjtWN3gHDA6mYysGdyL
depends:
    aeson-pretty-0.8.10-ECTNSZBvfddKJSTE9dZot9
    async-2.2.6-JvoT9znxQt2BsREADqk9DD base-4.18.2.1
    base16-bytestring-1.0.2.0-foJ0cLokH36TuDy5qj9u bytestring-0.11.5.3
    containers-0.6.7 cryptohash-sha1-0.11.101.0-FhBT6ylasXuA7limmVczUY
    data-default-0.7.1.3-EBr9yihfmglqiJThokEFL directory-1.3.8.5
    extra-1.7.16-9jmcA0IdNtHBNVuTvKhJcq filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-JpVyJ8mosujASoTdB9Rubc
    githash-0.1.7.0-2ROuo1OF70xHbYEhs0VwUI
    hie-bios-0.12.0-CODoQDzSIs18vMLkN0FPu7
    hiedb-0.4.3.0-9GeZdNRB3XPIhARb2CfQ63
    hls-alternate-number-format-plugin-2.3.0.0-IjHVNC5w4mU39gcDShhMeB
    hls-cabal-fmt-plugin-2.3.0.0-HFuNPARtqgLI2JUUShfm78
    hls-cabal-plugin-2.3.0.0-IioIiKZj1MrCUNlxxad9px
    hls-call-hierarchy-plugin-2.3.0.0-2ywgF8MKsii8Fb3pMMSAyD
    hls-change-type-signature-plugin-2.3.0.0-tw50LCVDZLJpovrVbS59W
    hls-class-plugin-2.3.0.0-IsQb9iqJtmJ6cgjwzP2O09
    hls-code-range-plugin-2.3.0.0-7YOtWn29u55A6UwKXskz8a
    hls-eval-plugin-2.3.0.0-4kKul6pu1DLDVkV0MRvjty
    hls-explicit-fixity-plugin-2.3.0.0-D84nta05eL2Lu1WkwjXGu9
    hls-explicit-imports-plugin-2.3.0.0-LOTuAQaEJxZ6ibqV64Z7M0
    hls-explicit-record-fields-plugin-2.3.0.0-CJCPLsaMI2L3HihwR0MrJx
    hls-fourmolu-plugin-2.3.0.0-EBNSaHDtEIgJf1VjOLwIHp
    hls-gadt-plugin-2.3.0.0-RZlQmM01J0CdOHEAqdaiT
    hls-graph-2.3.0.0-3wyhIKi1lFkAxX3TgjU1gJ
    hls-hlint-plugin-2.3.0.0-LXi18yreI5iBfEJ75FMMlV
    hls-module-name-plugin-2.3.0.0-9bxokXHxSprBMBowj9EynL
    hls-ormolu-plugin-2.3.0.0-LdUhsz7EHKHJo3Pcgarmjz
    hls-overloaded-record-dot-plugin-2.3.0.0-3nwXIGToJr9DCbXiOaCuV4
    hls-plugin-api-2.3.0.0-CVlAebno3ls9zFxI5yr51d
    hls-pragmas-plugin-2.3.0.0-CxSI5SYXgM41QRhpNUbjpv
    hls-qualify-imported-names-plugin-2.3.0.0-IKJCuN3090cIFSOThhUJum
    hls-refactor-plugin-2.3.0.0-El6MyJAkLptLhE07tC4F1m
    hls-rename-plugin-2.3.0.0-1bhtFbM8JZ5fjMiE395ZW
    hls-retrie-plugin-2.3.0.0-6XgGoOgFpqoGSrbCFuFsYE
    hls-splice-plugin-2.3.0.0-AQusBfZ7hoPGGySGsBV7Ff
    hls-stylish-haskell-plugin-2.3.0.0-6lliX7bIk0CFeu1SUqKnK0
    lsp-2.2.0.0-1X9YJaCHG0VDE34L6Es6OV
    optparse-applicative-0.18.1.0-HIDucWLVsMnBph0dP0V3D6
    optparse-simple-0.1.1.4-Fi1ZXw77u2j34KBcOXRGYB
    prettyprinter-1.7.1-FXUWMyidK0kKTeGVgF64vT process-1.6.19.0
    safe-exceptions-0.1.7.4-AJi6AhcOU2XILudArjgfZI
    sqlite-simple-0.4.19.0-1b8uJwPAaM02sxo6TTUme0 text-2.0.2
    unordered-containers-0.2.20.1-owJOmMRhDW8XCXGWMsAkD

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

